==> docx4j-openxml-objects-8.3.11-sources.jar: org/docx4j/dml/diagram/STClrAppMethod.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ClrAppMethod.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ClrAppMethod"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="span"/&gt;
 *     &lt;enumeration value="cycle"/&gt;
 *     &lt;enumeration value="repeat"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_ClrAppMethod")
@XmlEnum
public enum STClrAppMethod {


    /**
     * Span
     * 
     */
    @XmlEnumValue("span")
    SPAN("span"),

    /**
     * Cycle
     * 
     */
    @XmlEnumValue("cycle")
    CYCLE("cycle"),

    /**
     * Repeat
     * 
     */
    @XmlEnumValue("repeat")
    REPEAT("repeat");
    private final String value;

    STClrAppMethod(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STClrAppMethod fromValue(String v) {
        for (STClrAppMethod c: STClrAppMethod.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-11.4.7-sources.jar: org/docx4j/dml/diagram/STClrAppMethod.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ClrAppMethod.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ClrAppMethod"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="span"/&gt;
 *     &lt;enumeration value="cycle"/&gt;
 *     &lt;enumeration value="repeat"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_ClrAppMethod")
@XmlEnum
public enum STClrAppMethod {


    /**
     * Span
     * 
     */
    @XmlEnumValue("span")
    SPAN("span"),

    /**
     * Cycle
     * 
     */
    @XmlEnumValue("cycle")
    CYCLE("cycle"),

    /**
     * Repeat
     * 
     */
    @XmlEnumValue("repeat")
    REPEAT("repeat");
    private final String value;

    STClrAppMethod(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STClrAppMethod fromValue(String v) {
        for (STClrAppMethod c: STClrAppMethod.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
